@@ -135,6 +135,8 @@ DEFAULT_TEMPLATES = {
     'issuetrackerdtml'   : loadDtmlMethod('issuetrackerdtml'),
     'filterissues'       : loadPageTemplate('filterissues'),
     'filterissuesdtml'   : loadDtmlMethod('filterissuesdtml'),
+    'issuebrowser'       : loadPageTemplate('issuebrowser'),
+    'issuebrowserdtml'   : loadDtmlMethod('issuebrowserdtml'),
     'stylesheet'         : loadStylesheetFile('stylesheet.css'),
     }
 
@@ -270,13 +272,19 @@ class UIUtils:
         """
         Change the user's CMF/Plone skin preference, if possible.
         """
+        # are we in a CMF site ?
         if not self.inCMF(): return
         portal_skins = self.portal_url.getPortalObject().portal_skins
         portal_membership = self.portal_url.getPortalObject().portal_membership
+        # does the named skin exist ?
         def hasSkin(s): return portal_skins.getSkinPath(s) != s
         if not hasSkin(skin): return
+        # is the user logged in ? 
+        member = portal_membership.getAuthenticatedMember()
+        if not hasattr(member,'setProperties'): return
+        # change their skin preference and reload page
         REQUEST.form['portal_skin'] = skin
-        portal_membership.getAuthenticatedMember().setProperties(REQUEST)
+        member.setProperties(REQUEST)
         portal_skins.updateSkinCookie()
         REQUEST.RESPONSE.redirect(REQUEST.get('URL1'))
 
@@ -547,6 +555,22 @@ class GeneralForms:
         else:
             return form(self,REQUEST)
 
+    security.declareProtected(Permissions.View, 'issuebrowser')
+    def issuebrowser(self, REQUEST=None):
+        """
+        Render the issuebrowser form (template-customizable).
+
+        The default page template calls a DTML helper template,
+        for ease of syncing with the evolving wiki-page-based version.
+        """
+        form = self.getSkinTemplate('issuebrowser')
+        dtmlpart = self.getSkinTemplate('issuebrowserdtml')
+        # XXX kludge - a customized template may not require our dtml part
+        if re.search(r'"structure options/body',form.read()):
+            return form(self,REQUEST,body=dtmlpart(self,REQUEST))
+        else:
+            return form(self,REQUEST)
+
     security.declareProtected(Permissions.View, 'editConflictDialog')
     def editConflictDialog(self):
         """
