@@ -44,12 +44,11 @@ ISSUE_COLOURS = [
     ',open,wishlist ,#e0e0e0',
     ',open,         ,#ffe0e0',
     ',pending,      ,#ffcc77',
-    ',closed,       ,#e0f0e0',
+    ',closed,       ,#bbeebb',
     ',,             ,',
     ]
 
-
-for a in [
+TRACKER_METADATA = [
     'category',
     'category_index',
     'severity',
@@ -57,8 +56,8 @@ for a in [
     'status',
     'status_index',
     'issueColour',
-    ]:
-    registerPageMetaData(a)
+    ]
+for a in TRACKER_METADATA: registerPageMetaData(a)
 
 
 class TrackerSupport:
@@ -224,7 +223,7 @@ class TrackerSupport:
                                       severity=severity,
                                       status=status
                                       )
-        self.reindex_object()
+        self.index_object()
 
     security.declareProtected(Permissions.Add, 'createNextIssue')
     def createNextIssue(self,name='',text='',category='',severity='',status='',
@@ -299,7 +298,7 @@ class TrackerSupport:
         log = log or 'property change'
         self.comment(text=comment, subject_heading=log, REQUEST=REQUEST)
         self.setLastEditor(REQUEST)
-        self.reindex_object()
+        self.index_object()
         if REQUEST: REQUEST.RESPONSE.redirect(self.page_url())
 
     def category_index(self):
@@ -406,8 +405,7 @@ class TrackerSupport:
         - if pages=1, installs forms as DTML pages, for easy customizing
         
         Safe to call more than once; will ignore any already existing
-        items.  Based on the setupIssueTracker.py external method and the
-        data at http://zwiki.org/ZwikiAndZCatalog.
+        items.  
         """
         TextIndexes = [
             ]
@@ -415,6 +413,7 @@ class TrackerSupport:
             'category',
             'category_index',
             'isIssue',
+            'issueNumber',
             'severity',
             'severity_index',
             'status',
@@ -426,15 +425,6 @@ class TrackerSupport:
             ]
         PathIndexes = [
             ]
-        metadata = [
-            'category',
-            'category_index',
-            'issueColour',
-            'severity',
-            'severity_index',
-            'status',
-            'status_index',
-            ]
         # make sure we have a basic zwiki catalog set up
         self.setupCatalog(reindex=0)
         catalog = self.catalog()
@@ -452,14 +442,16 @@ class TrackerSupport:
         for i in PathIndexes:
             if not i in catalogindexes: PluginIndexes.manage_addPathIndex(i)
         # metadata,
-        for m in metadata:
-            if not m in catalogmetadata: catalog.manage_addColumn(m)
+        # setupCatalog just does this by default now, since
+        # ensureCompleteMetadataIn always tries to fetch all metadata
+        #for m in TRACKER_METADATA:
+        #    if not m in catalogmetadata: catalog.manage_addColumn(m)
         # properties,
         self.upgradeFolderIssueProperties()
         # dtml pages,
         if pages:
             dir = package_home(globals())+os.sep+'tracker'+os.sep
-            for page in ['IssueTracker','FilterIssues']:
+            for page in ['IssueTracker','FilterIssues','IssueBrowser']:
                 if not self.pageWithName(page):
                     self.create(page,
                                 text=open(dir+page+'.stxdtml','r').read(),
